@@ -1,4 +1,5 @@
 from enum import Enum, auto
+from inspect import _ParameterKind
 
 
 class NoValue(Enum):
@@ -12,3 +13,7 @@ class ParameterType(NoValue):
     VAR_POSITIONAL = auto()
     KEYWORD_ONLY = auto()
     VAR_KEYWORD = auto()
+
+    @classmethod
+    def from_kind(cls, kind: _ParameterKind, /) -> "ParameterType":
+        return getattr(cls, kind.name)
